==> dbstyleguidechecker-3.0.2.tar.gz: lib/src/checkers/flutter_project_style_guide_checker.dart <==
/*
 * BSD 3-Clause License
 *
 * Copyright (c) 2020, Bitsy Darel
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived from
 *    this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import 'dart:convert';
import 'dart:io';

import 'package:dbstyleguidechecker/src/checkers/dart_project_style_guide_checker.dart';
import 'package:dbstyleguidechecker/src/exceptions.dart';
import 'package:dbstyleguidechecker/src/parsers/code_style_violations_parser.dart';
import 'package:dbstyleguidechecker/src/reporters/code_style_violations_reporter.dart';

/// Flutter project style guide linter.
class FlutterProjectStyleGuideChecker extends DartProjectStyleGuideChecker {
  /// create a Flutter code style guide linter.
  const FlutterProjectStyleGuideChecker(
    File styleGuide,
    Directory projectDir,
    CodeStyleViolationsParser parser,
    CodeStyleViolationsReporter reporter,
  ) : super(styleGuide, projectDir, parser, reporter);

  @override
  Future<void> runPubGet() {
    return Process.run(
      'flutter',
      <String>['pub', 'get'],
      runInShell: true,
      stderrEncoding: utf8,
      stdoutEncoding: utf8,
    ).then<void>((ProcessResult result) {
      final String errorOutput = result.stderr.toString();

      if (errorOutput.isNotEmpty) {
        throw UnrecoverableException(
          'could not run flutter packages get: $errorOutput',
          exitPackageUpdatedFailed,
        );
      }
    });
  }
}

==> dbstyleguidechecker-3.0.3.tar.gz: lib/src/checkers/flutter_project_style_guide_checker.dart <==
/*
 * BSD 3-Clause License
 *
 * Copyright (c) 2020, Bitsy Darel
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived from
 *    this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import 'dart:convert';
import 'dart:io';

import 'package:dbstyleguidechecker/src/checkers/code_style_violations_checker.dart';
import 'package:dbstyleguidechecker/src/checkers/dart_project_style_guide_checker.dart';
import 'package:dbstyleguidechecker/src/exceptions.dart';
import 'package:dbstyleguidechecker/src/parsers/code_style_violations_parser.dart';
import 'package:dbstyleguidechecker/src/reporters/code_style_violations_reporter.dart';

/// Flutter project style guide linter.
class FlutterProjectStyleGuideChecker extends DartProjectStyleGuideChecker {
  /// create a Flutter code style guide linter.
  const FlutterProjectStyleGuideChecker(
    File styleGuide,
    Directory projectDir,
    CodeStyleViolationsParser parser,
    CodeStyleViolationsReporter reporter,
  ) : super(styleGuide, projectDir, parser, reporter);

  @override
  Future<void> runPubGet() {
    return Process.run(
      'flutter',
      <String>['pub', 'get'],
      runInShell: true,
      stderrEncoding: utf8,
      stdoutEncoding: utf8,
    ).then<void>((ProcessResult result) {
      final String errorOutput = result.stderr.toString();

      if (!errorOutput.contains(dependenciesOverridden) &&
          errorOutput.isNotEmpty) {
        throw UnrecoverableException(
          'could not run flutter packages get: $errorOutput',
          exitPackageUpdatedFailed,
        );
      }
    });
  }
}
